@@ -13,7 +13,7 @@ class Postgres:
         self.slot = slot
 
     def run_cmd(self, cmd):
-        execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} -d {self.dbname} -c {cmd}',
+        execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} -d {self.dbname} -c "{cmd}"',
                      env=[('PGPASSWORD', self.password)])
 
     def force_switch_wal(self):
